@@ -103,6 +103,6 @@ setReplaceMethod(".leftBracket",
 setMethod(".addhandlerchanged",
           signature(toolkit="guiWidgetsToolkitRGtk2",obj="gSpinbuttonRGtk"),
           function(obj, toolkit, handler, action=NULL, ...) {
-            addhandler(obj,"value-changed",handler, action)
+            addhandler(obj,"value-changed",handler, action, ...)
           })
 
